@@ -8,7 +8,7 @@ use Data::Dumper;
 use Carp;
 use Log::LTSV::Instance::Flatten;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 my %LOG_LEVEL_MAP = (
     DEBUG    => 1,
@@ -67,9 +67,19 @@ sub sticks {
     }
 }
 
+sub _escape {
+    my ($self, $val) = @_;
+
+    $val =~ s/\t/\\t/;
+    $val =~ s/\n/\\n/;
+
+    return $val;
+}
+
 sub labeled_values {
     my ($self, $key, $value) = @_;
     my %lv = $self->{_flatten}->flatten($key, $value);
+    $lv{$_} = $self->_escape($lv{$_}) for ( keys %lv );
     map { join ':', $_, $lv{$_} } keys %lv;
 }
 
